# 7DS-Forecast
A prediction study of photometric redshifts in upcoming 7-Dimensional Sky Survey

**This repo is heavily under constuction!**

* [Test page](https://eunheeko.github.io/7DS-Forecast/)

# Prediction

## Data Specifiaction
![data_spec](/images/data_specification.png)

## Survey Plan
=======
# Notes


## EAZY
<!-- - read binary files: https://github.com/gbrammer/eazy-photoz/tree/f8b84a20f8e781d1f8244a24cd347a24a40f1558/inputs -->
<!-- - source code: https://eazy-py.readthedocs.io/en/latest/_modules/eazy/photoz.html -->


## data/filters
* 7DS, SPHERE: customized
* LSST: 
* [EUCLID](https://ui.adsabs.harvard.edu/abs/2022A%26A...662A..92E/abstract): [data](https://euclid.esac.esa.int/msp/refdata/data/)
* VIKIG: 